aboutsummaryrefslogtreecommitdiffstats
path: root/prototypes/workbench/qa-document-guards.js
diff options
context:
space:
mode:
authoreunhhu <[email protected]>2026-10-09 14:14:16 +0100
committereunhhu <[email protected]>2026-10-09 14:14:16 +0100
commit2427fbe9227de6fcea13addaf7ca6d82d9829957 (patch)
treeb0071acd2c4ad48b8350131d3b0af40b33e407de /prototypes/workbench/qa-document-guards.js
parentf3993efb0c7c38954e991918d66aaca3981bc69c (diff)
downloadpure-2427fbe9227de6fcea13addaf7ca6d82d9829957.tar.gz
pure-2427fbe9227de6fcea13addaf7ca6d82d9829957.zip
Design 025: stage 5's bars measured again on b16: BFS's candidate tail about 5.7 ms of 24.1 (decide, keep_filtered, apply_filters and the list side), halved 21.5 ms; join's sums into cells about 17 ns a round, a chain through the same cells, in four-byte integers with the width once a batch about 5 ns, 108 ms; neither moves BFS from about 2.7x the compiled code, and join's recurrence (about 40 ms) stays outside
Diffstat (limited to 'prototypes/workbench/qa-document-guards.js')
0 files changed, 0 insertions, 0 deletions